import React, { useState, useEffect, useRef } from 'react';
import { Node, mergeAttributes } from '@tiptap/core';
import {Editor, ReactNodeViewRenderer } from '@tiptap/react';
import { ZoomIn, ZoomOut } from 'lucide-react';
import { Node as ProseMirrorNode } from 'prosemirror-model';


interface ImageNodeViewProps {
  node: ProseMirrorNode;
  updateAttributes: (attrs: Record<string, number>) => void;
  editor: Editor;
  getPos: () => number;
}

// React component for the image node view
const ImageNodeView: React.FC<ImageNodeViewProps> = ({ node, updateAttributes, editor, getPos }) => {
  const [isSelected, setIsSelected] = useState(false);
  const [scale, setScale] = useState(1);
  const imageRef = useRef<HTMLImageElement>(null);

  // Update selection state when the editor selection changes
  useEffect(() => {
    const handleSelectionUpdate = ({ editor }: { editor: Editor }) => {
      const { state } = editor;
      const { selection } = state;
      const nodePos = getPos();

      // Check if this node is selected
      const isNodeSelected = selection.$anchor.pos >= nodePos &&
          selection.$anchor.pos <= nodePos + node.nodeSize;

      setIsSelected(isNodeSelected);
    };

    editor.on('selectionUpdate', handleSelectionUpdate);
    return () => {
      editor.off('selectionUpdate', handleSelectionUpdate);
    };
  }, [editor, getPos, node.nodeSize]);

  // Handle zoom in
  const handleZoomIn = (e: React.MouseEvent) => {
    e.stopPropagation();
    setScale(prev => Math.min(prev + 0.1, 2));
    updateAttributes({ scale: Math.min(scale + 0.1, 2) });
  };

  // Handle zoom out
  const handleZoomOut = (e: React.MouseEvent) => {
    e.stopPropagation();
    setScale(prev => Math.max(prev - 0.1, 0.5));
    updateAttributes({ scale: Math.max(scale - 0.1, 0.5) });
  };

  // Track current scale from attributes
  useEffect(() => {
    if (node.attrs.scale) {
      setScale(node.attrs.scale);
    }
  }, [node.attrs.scale]);

  return (
    <div className="relative flex justify-center my-4">
        {/* The actual image */}
        <img
          ref={imageRef}
          src={node.attrs.src}
          alt={node.attrs.alt || ''}
          className={`max-w-full transition-transform ${isSelected ? 'ring-2 ring-blue-500' : ''}`}
          style={{
            transform: `scale(${scale})`,
            transformOrigin: 'center',
          }}
          data-drag-handle=""
        />

        {/* Zoom controls - only visible when selected */}
        {isSelected && (
            <div className="absolute top-2 right-2 flex space-x-2 bg-white bg-opacity-75 p-1 rounded shadow">
            <button
                onClick={handleZoomIn}
          className="p-1 rounded hover:bg-gray-200"
          title="Zoom in"
          >
          <ZoomIn size={16} />
        </button>
        <button
          onClick={handleZoomOut}
          className="p-1 rounded hover:bg-gray-200"
          title="Zoom out"
          >
          <ZoomOut size={16} />
        </button>
        </div>
        )}
    </div>
  );
};

// Custom Image extension for TipTap
export const CustomImage = Node.create({
  name: 'customImage',
  group: 'block',
  inline: false,
  selectable: true,
  draggable: true,
  atom: true,

  addAttributes() {
    return {
      src: {
        default: null,
      },
      alt: {
        default: null,
      },
      title: {
        default: null,
      },
      scale: {
        default: 1,
      },
    };
  },

  parseHTML() {
    return [
      {
        tag: 'img[src]',
      },
    ];
  },

  renderHTML({ HTMLAttributes }) {
    const { scale, ...rest } = HTMLAttributes;
    return [
      'div',
      { class: 'flex justify-center my-4' },
      ['img', mergeAttributes(rest, { style: `transform: scale(${scale})` })],
    ];
  },

  addNodeView() {
    return ReactNodeViewRenderer(ImageNodeView);
  },
});
