import React, { useState, useEffect, useMemo } from 'react';
import axios from "axios";
import { TipTapEditor } from '../components/TipTapEditor';
import { Header } from '../components/Header';
import { GalleryManager } from '../components/GalleryManager';
import { CoverImageUpload } from '../components/ImageUpload/CoverImageUpload';
import { ImageUploader } from '../components/ImageUpload/ImageUploader';
import { useGallery } from '../hooks/useGallery';
import MinutesWord from '../components/MinutesWord';
import { CategoryTitles, CityTitles, CategoryIds, CityIds, Article, Author } from '../types';
import { Pencil, Trash2, ChevronLeft, ChevronRight, ImagePlus, X, ToggleLeft, ToggleRight} from 'lucide-react';
import { useAuthStore } from '../stores/authStore';

const allCategoryIds: number[] = CategoryIds;
const allCityIds: number[] = CityIds;

// Обложка по умоланию для новых статей
const DEFAULT_COVER_IMAGE = '/images/cover-placeholder.webp';


export function AdminPage() {
  const { user } = useAuthStore();
  const isAdmin = user?.permissions.isAdmin || false;

  const [articleId, setArticleId] = useState('');
  const [title, setTitle] = useState('');
  const [excerpt, setExcerpt] = useState('');
  const [categoryId, setCategoryId] = useState(1);
  const [cityId, setCityId] = useState(1);
  const [coverImage, setCoverImage] = useState(DEFAULT_COVER_IMAGE);
  const [readTime, setReadTime] = useState(5);
  const [showGalleryUploader, setShowGalleryUploader] = useState(false);
  const [editingId, setEditingId] = useState<string | null>(null);
  const [showDeleteModal, setShowDeleteModal] = useState<string | null>(null);
  const [articles, setArticles] = useState<Article[]>([]);
  const [refreshArticles, setRefreshArticles] = useState(0);
  const [totalPages, setTotalPages] = useState(1);
  const [currentPage, setCurrentPage] = useState(1);
  const [filterCategoryId, setFilterCategoryId] = useState(0);
  const [filterCityId, setFilterCityId] = useState(0);
  const [error, setError] = useState<string | null>(null);
  const [content, setContent] = useState('');
  const [showDraftOnly, setShowDraftOnly] = useState(false);
  const [authors, setAuthors] = useState<Author[]>([]);
  const [authorId, setAuthorId] = useState<string>('');
  const [newImageUrl, setNewImageUrl] = useState('');

  // Инициализация хука useGallery с текущим значением articleId (editingId)
  const {
    images: galleryImages,
    loading: galleryLoading,
    error: galleryError,
//    addImage: addGalleryImage,
//    updateImage: updateGalleryImage,
//    deleteImage: deleteGalleryImage,
    reorderImages: reorderGalleryImages,
//    refresh: refreshGallery
  } = useGallery(editingId || '');

  // Загрузка списка авторов
  useEffect(() => {
    const fetchAuthors = async () => {
      try {
        const response = await axios.get('/api/users/' , {
            headers: {
              Authorization: `Bearer ${localStorage.getItem('token')}`,
            },
        });

        setAuthors(response.data);
      } catch (err) {
        console.error('Ошибка загрузки авторов:', err);
        setError('Не удалось загрузить список авторов.');
      }
    };

    fetchAuthors();
  }, []);

  // Загрузка статей
  useEffect(() => {
    const fetchArticles = async () => {
      try {
        const response = await axios.get('/api/articles/', {
          params: {
            page: currentPage,
            categoryId: filterCategoryId,
            cityId: filterCityId,
            isDraft: showDraftOnly,
            userId: user?.id,
            isAdmin: isAdmin
          }
        });
        setArticles(response.data.articles);
        setTotalPages(response.data.totalPages); // Берём totalPages из ответа
      } catch (error) {
        setError('Не удалось загрузить статьи');
        console.error(error);
      }
    };

    fetchArticles();
  }, [currentPage, filterCategoryId, filterCityId, showDraftOnly, refreshArticles]);

  const handlePageChange = (page: number) => {
    setCurrentPage(page);
  };

  // Фильтр для категорий, основанный на разрешениях пользователя
  const availableCategoryIds = useMemo(() => {
    if (!user) return [];
    if (isAdmin) return allCategoryIds;

    return allCategoryIds.filter(categoryId =>
        user.permissions.categories[categoryId] &&
       (user.permissions.categories[categoryId].create || user.permissions.categories[categoryId].edit)
    );
  }, [user, isAdmin]);

  // Фильтр для городов, основанный на разрешениях пользователя
  const availableCityIds = useMemo(() => {
    if (!user) return [];
    if (isAdmin) return allCityIds;

    return user.permissions.cities;
  }, [user, isAdmin]);

  // Установка категории и города по умолчанию на основе доступных параметров
  useEffect(() => {
    if (availableCategoryIds.length > 0 && !availableCategoryIds.includes(categoryId)) {
      setCategoryId(availableCategoryIds[0]);
    }

    if (availableCityIds.length > 0 && !availableCityIds.includes(cityId)) {
      setCityId(availableCityIds[0]);
    }
  }, [availableCategoryIds, availableCityIds, categoryId, cityId]);

  // Редактирование статьи - загрузка данных
  const handleEdit = (id: string) => {
    const article = articles.find(a => a.id === id);
    if (article) {
      setArticleId(article.id);
      setTitle(article.title);
      setExcerpt(article.excerpt);
      setCategoryId(article.categoryId);
      setCityId(article.cityId);
      setCoverImage(article.coverImage);
      setReadTime(article.readTime);
      setAuthorId(article.author.id);
      setContent(article.content);
      setEditingId(id);
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }
  };

  // Удаление статьи
  const handleDelete = async (id: string) => {
    try {
      await axios.delete(`/api/article/${id}`, {
        headers: {
          Authorization: `Bearer ${localStorage.getItem('token')}`,
        },
      });
      setArticles(prev => ({
        ...prev,
        articles: prev.filter(article => article.id !== id),
      }));

      setRefreshArticles(prev => prev + 1);
    } catch (error) {
      setError('Не удалось удалить статью');
      console.error(error);
    }
    setShowDeleteModal(null);
  };

  // Перевод статьи в черновик и обратно
  const handleToggleActive = async (id: string) => {
    const article = articles.find(a => a.id === id);
    if (article) {
      const articleData = {
        isActive: article.isActive,
      };

      try {
        await axios.put(`/api/articles/active/${id}`, articleData, {
          headers: {
            Authorization: `Bearer ${localStorage.getItem('token')}`,
          },
        });

        setArticles(prev => prev.map(article =>
            article.id === id ? {...article, isActive: !article.isActive} : article
        ));
      } catch (error) {
        setError('Не переключить статью в актив');
        console.error(error);
      }
    }
  };

  // Создание новой статьи, сохранение существующей
  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();

    let selectedAuthor;

    if (editingId) {
      if (isAdmin) {
        selectedAuthor = authors.find(author => author.id === authorId) || authors[0];
      } else {
        // Пользователь без административных прав не может менять автора
        const originalArticle = articles.find(a => a.id === editingId);
        selectedAuthor = originalArticle?.author || authors[0];
      }
    } else {
      // Для новой статьи всегда использовать текущего пользователя
      selectedAuthor = user;
    }

    const articleData = {
      title,
      excerpt,
      categoryId,
      cityId,
      coverImage,
      readTime,
      gallery: galleryImages,
      content: content || '',
      importId: 0,
      isActive: false,
      author: selectedAuthor
    };

    if (editingId) {
      // Редактирование существующей статьи
      try {
        const response = await axios.put(`/api/articles/${editingId}`, articleData, {
          headers: {
            Authorization: `Bearer ${localStorage.getItem('token')}`,
          },
        });

        setArticles(prev => prev.map(article => article.id === editingId ? response.data : article));
      } catch (error) {
        setError('Не удалось обновить статью');
        console.error(error);
      }

      setEditingId(null);
    }
    else {
      // Создание новой статьи
      try {
        const response = await axios.post('/api/articles', articleData, {
          headers: {
            Authorization: `Bearer ${localStorage.getItem('token')}`,
          },
        });

        setArticles(prev => [...prev, response.data]);
      } catch (error) {
        setError('Не удалось создать статью');
        console.error(error);
      }
    }

    setRefreshArticles(prev => prev + 1);

    // Очистка формы статьи
    setArticleId('');
    setTitle('');
    setExcerpt('');

    if (availableCategoryIds.length > 0) {
      setCategoryId(availableCategoryIds[0]);
    }
    if (availableCityIds.length > 0) {
      setCityId(availableCityIds[0]);
    }

    setCoverImage(DEFAULT_COVER_IMAGE);
    setReadTime(5);
    setAuthorId(authors[0].id || '');
    setContent('');

    setEditingId(null);
  };

  // Проверка прав пользователя
  const hasNoPermissions = availableCategoryIds.length === 0 || availableCityIds.length === 0;

/*
  const handleGalleryImageUpload = async (imageUrl: string) => {
    try {
      await addGalleryImage({
        url: imageUrl,
        caption: '',
        alt: '',
        width: 0,
        height: 0,
        size: 0,
        format: 'webp'
      });
      setShowGalleryUploader(false);
    } catch  {
      setError('Failed to add gallery image');
    }
  };
*/

  // Show loading state while gallery is loading
  if (editingId && galleryLoading) {
    return (
        <div className="min-h-screen flex items-center justify-center">
          <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-blue-600"></div>
        </div>
    );
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <Header />
      <main className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        {hasNoPermissions ? (
            <div className="bg-white rounded-lg shadow-sm p-6 mb-8 text-center">
              <h1 className="text-2xl font-bold text-gray-900 mb-4">
                Недостаточно прав
              </h1>
              <p className="text-gray-600 mb-4">
                У вас нет прав на создание и редактирование статей в любой категории и городе.
                Свяжитесь с администраторм чтобы получить права.
              </p>
            </div>
        ) : (
        <div className="bg-white rounded-lg shadow-sm p-6 mb-8">
          <h1 className="text-2xl font-bold text-gray-900 mb-6">
            {editingId ? 'Редактировать статью' : 'Создать новую статью'}
          </h1>

          {(error  || galleryError) && isAdmin && (
            <div className="mb-6 bg-red-50 text-red-700 p-4 rounded-md">
              {error || galleryError}
            </div>
          )}

          <form onSubmit={handleSubmit} className="space-y-6">
            <div>
              <label htmlFor="title" className="block text-sm font-medium text-gray-700">
                <span className="italic font-bold">Заголовок</span>
              </label>
              <input
                type="text"
                id="title"
                value={title}
                onChange={(e) => setTitle(e.target.value)}
                className="px-2 py-1 mt-1 block w-full rounded-lg border border-gray-300 shadow-sm hover:border-blue-300 focus:border-blue-500 focus:ring-4 focus:ring-blue-100 transition-all duration-200"
                required
              />
            </div>

            <div>
              <label htmlFor="excerpt" className="block text-sm font-medium text-gray-700">
                <span className="italic font-bold">Краткое описание</span>
              </label>
              <textarea
                id="excerpt"
                rows={3}
                value={excerpt}
                onChange={(e) => setExcerpt(e.target.value)}
                className="px-2 py-1 mt-1 block w-full rounded-lg border border-gray-300 shadow-sm hover:border-blue-300 focus:border-blue-500 focus:ring-4 focus:ring-blue-100 transition-all duration-200"
                required
              />
            </div>

            <div className="grid grid-cols-1 gap-6 sm:grid-cols-2">
              <div>
                <label htmlFor="category" className="block text-sm font-medium text-gray-700">
                  <span className="italic font-bold">Категория</span>
                </label>
                <select
                  id="category"
                  value={categoryId}
                  onChange={(e) => setCategoryId(Number(e.target.value))}
                  className="px-2 py-1 mt-1 block w-full rounded-lg border border-gray-300 shadow-sm hover:border-blue-300 focus:border-blue-500 focus:ring-4 focus:ring-blue-100 transition-all duration-200"
                >
                  {availableCategoryIds.map((cat) => (
                    <option key={cat} value={cat}>
                      {CategoryTitles[cat]}
                    </option>
                  ))}
                </select>
              </div>

              <div>
                <label htmlFor="city" className="block text-sm font-medium text-gray-700">
                  <span className="italic font-bold">Столица</span>
                </label>
                <select
                  id="city"
                  value={cityId}
                  onChange={(e) => setCityId(Number(e.target.value))}
                  className="px-2 py-1 mt-1 block w-full rounded-lg border border-gray-300 shadow-sm hover:border-blue-300 focus:border-blue-500 focus:ring-4 focus:ring-blue-100 transition-all duration-200"
                >
                  {availableCityIds.map((c) => (
                    <option key={c} value={c}>
                      {CityTitles[c]}
                    </option>
                  ))}
                </select>
              </div>

              <div>
                <label htmlFor="readTime" className="block text-sm font-medium text-gray-700">
                  <span className="italic font-bold">Время чтения (минуты)</span>
                </label>
                <input
                  type="number"
                  id="readTime"
                  min="1"
                  value={readTime}
                  onChange={(e) => setReadTime(Number(e.target.value))}
                  className="px-2 py-1 mt-1 block w-full rounded-lg border border-gray-300 shadow-sm hover:border-blue-300 focus:border-blue-500 focus:ring-4 focus:ring-blue-100 transition-all duration-200"
                />
              </div>

              {editingId && isAdmin && (
                <div>
                  <label htmlFor="author" className="block text-sm font-medium text-gray-700">
                    <span className="italic font-bold">Автор</span>
                  </label>
                  <select
                      id="author"
                      value={authorId}
                      onChange={(e) => setAuthorId(e.target.value)}
                      className="px-2 py-1 mt-1 block w-full rounded-lg border border-gray-300 shadow-sm hover:border-blue-300 focus:border-blue-500 focus:ring-4 focus:ring-blue-100 transition-all duration-200"
                  >
                    {authors.map((author) => (
                        <option key={author.id} value={author.id}>
                          {author.displayName}
                        </option>
                    ))}
                  </select>
                </div>
              )}

            </div>

            <CoverImageUpload
              coverImage={coverImage}
              articleId={articleId}
              onImageUpload={setCoverImage}
              onError={setError}
              allowUpload={!!editingId}
            />

            <div>
              <label className="block text-sm font-medium text-gray-700">
                <span className="italic font-bold">Статья</span>
              </label>
              <TipTapEditor initialContent={content} onContentChange={setContent} atricleId={articleId}/>
            </div>
            <div>
              <div className="flex justify-between items-center mb-4">
                <label className="block text-sm font-medium text-gray-700">
                  <span className="italic font-bold">Фото галерея</span>
                </label>
                {editingId && (
                  <button
                      type="button"
                      onClick={() => setShowGalleryUploader(true)}
                      className="inline-flex items-center px-3 py-2 border border-gray-300 shadow-sm text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50"
                  >
                    <ImagePlus size={16} className="mr-2" />
                    Загрузить фото
                  </button>
                )}
              </div>
              <GalleryManager
                  images={galleryImages}
                  imageUrl={newImageUrl}
                  onChange={(images) => {
                    // Обработка реорганизации галереи через хук
                    reorderGalleryImages(images.map(img => img.id));
                  }}
              />
            </div>

            <div className="flex justify-end gap-4">
              {editingId && (
                <button
                  type="button"
                  onClick={() => {
                    setEditingId(null);
                    setTitle('');
                    setExcerpt('');
                    if (availableCategoryIds.length > 0) {
                      setCategoryId(availableCategoryIds[0]);
                    }
                    if (availableCityIds.length > 0) {
                      setCityId(availableCityIds[0]);
                    }
                    setCoverImage(DEFAULT_COVER_IMAGE);
                    setReadTime(5);
                    setAuthorId(authors[0].id || '');
                    setContent('');
                  }}
                  className="px-4 py-2 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
                >
                  Отмена
                </button>
              )}
              <button
                type="submit"
                className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
              >
                {editingId ? 'Изменить' : 'Сохранить черновик'}
              </button>
            </div>
          </form>
        </div>
        )}

        {/* Модальная загрузка изображений галереи */}
        {showGalleryUploader && (
            <div className="fixed inset-0 bg-gray-500 bg-opacity-75 flex items-center justify-center p-4 z-50">
              <div className="bg-white rounded-lg max-w-lg w-full p-6">
                <div className="flex justify-between items-center mb-4">
                  <h3 className="text-lg font-medium text-gray-900">
                    Загрузка изображений в галерею
                  </h3>
                  <button
                      onClick={() => setShowGalleryUploader(false)}
                      className="text-gray-400 hover:text-gray-500"
                  >
                    <X size={20} />
                  </button>
                </div>
                <ImageUploader onUploadComplete={(imageUrl) => {
                  setNewImageUrl(imageUrl);
                  setShowGalleryUploader(false);
                }}
                articleId={articleId}
                />
              </div>
            </div>
        )}

        {/* Список статей */}
        <div className="bg-white rounded-lg shadow-sm">
          <div className="px-6 py-4 border-b border-gray-200">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <h2 className="text-lg font-medium text-gray-900">Статьи</h2>
              <div className="flex flex-wrap gap-4">
                <select
                  value={filterCategoryId}
                  onChange={(e) => {
                    setFilterCategoryId(Number(e.target.value));
                    setCurrentPage(1);
                  }}
                  className="rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 text-sm"
                >
                  <option value="">Все категории</option>
                  {CategoryIds.map((cat) => (
                    <option key={cat} value={cat}>
                      {CategoryTitles[cat]}
                    </option>
                  ))}
                </select>
                <select
                  value={filterCityId}
                  onChange={(e) => {
                    setFilterCityId(Number(e.target.value));
                    setCurrentPage(1);
                  }}
                  className="rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 text-sm"
                >
                  <option value="">Все столицы</option>
                  {CityIds.map((c) => (
                    <option key={c} value={c}>
                      {CityTitles[c]}
                    </option>
                  ))}
                </select>
                <label className="inline-flex items-center">
                  <input
                      type="checkbox"
                      checked={showDraftOnly}
                      onChange={(e) => setShowDraftOnly(e.target.checked)}
                      className="rounded border-gray-300 text-blue-600 focus:ring-blue-500"
                  />
                  <span className="ml-2 text-sm text-gray-700">Только черновики</span>
                </label>
              </div>
            </div>
          </div>

          <ul className="divide-y divide-gray-200">
            {articles.map((article) => (
                <li
                    key={article.id}
                    className={`px-6 py-4 ${!article.isActive ? 'bg-gray-200' : ''}`}
                >
                <div className="flex items-center justify-between">
                  <div className="flex-1 min-w-0">
                    <h3 className="text-sm font-medium text-gray-900 truncate">
                      {article.title}
                    </h3>
                    <p className="text-sm text-gray-500">
                      · {CategoryTitles[article.categoryId]} · {CityTitles[article.cityId]} · {article.readTime} <MinutesWord minutes={article.readTime}/> чтения
                    </p>
                    <div className="flex items-center text-xs text-gray-500 mt-1">
                      <img
                          src={article.author.avatarUrl}
                          alt={article.author.displayName}
                          className="h-6 w-6 rounded-full mr-1"
                      />
                      <span className="italic font-bold"> {article.author.displayName}</span>
                    </div>

                  </div>
                  <div className="flex items-center gap-4 ml-4">
                    <button
                        onClick={() => handleToggleActive(article.id)}
                        className={`p-2 rounded-full hover:bg-gray-100 ${
                            article.isActive ? 'text-green-600' : 'text-gray-400'
                        }`}
                        title={article.isActive ? 'Set as draft' : 'Publish article'}
                    >
                      {article.isActive ? <ToggleRight size={18} /> : <ToggleLeft size={18} />}
                    </button>
                    <button
                      onClick={() => handleEdit(article.id)}
                      className="p-2 text-gray-400 hover:text-blue-600 rounded-full hover:bg-blue-50"
                    >
                      <Pencil size={18} />
                    </button>
                    <button
                      onClick={() => setShowDeleteModal(article.id)}
                      className="p-2 text-gray-400 hover:text-red-600 rounded-full hover:bg-red-50"
                    >
                      <Trash2 size={18} />
                    </button>
                  </div>
                </div>
              </li>
            ))}
          </ul>

          {/* Pagination */}
          {totalPages > 1 && (
            <div className="px-6 py-4 border-t border-gray-200">
              <div className="flex items-center justify-between">
                <div className="text-sm text-gray-500">
                  Показано {articles.length} статей
                </div>
                <div className="flex items-center space-x-2">
                  <button
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage === 1}
                    className="p-2 rounded-md text-gray-500 hover:text-gray-700 hover:bg-gray-100 disabled:opacity-50 disabled:cursor-not-allowed"
                  >
                    <ChevronLeft size={20} />
                  </button>
                  {Array.from({ length: totalPages }, (_, i) => i + 1).map((page) => (
                    <button
                      key={page}
                      onClick={() => handlePageChange(page)}
                      className={`px-4 py-2 text-sm font-medium rounded-md ${
                        currentPage === page
                          ? 'bg-blue-600 text-white'
                          : 'text-gray-700 hover:bg-gray-100'
                      }`}
                    >
                      {page}
                    </button>
                  ))}
                  <button
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage === totalPages}
                    className="p-2 rounded-md text-gray-500 hover:text-gray-700 hover:bg-gray-100 disabled:opacity-50 disabled:cursor-not-allowed"
                  >
                    <ChevronRight size={20} />
                  </button>
                </div>
              </div>
            </div>
          )}
        </div>
      </main>

      {/* Delete Confirmation Modal */}
      {showDeleteModal && (
        <div className="fixed inset-0 bg-gray-500 bg-opacity-75 flex items-center justify-center p-4">
          <div className="bg-white rounded-lg max-w-md w-full p-6">
            <h3 className="text-lg font-medium text-gray-900 mb-4">
              Delete Article
            </h3>
            <p className="text-sm text-gray-500 mb-6">
              Are you sure you want to delete this article? This action cannot be undone.
            </p>
            <div className="flex justify-end gap-4">
              <button
                onClick={() => setShowDeleteModal(null)}
                className="px-4 py-2 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 bg-white hover:bg-gray-50"
              >
                Cancel
              </button>
              <button
                onClick={() => handleDelete(showDeleteModal)}
                className="px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-red-600 hover:bg-red-700"
              >
                Delete
              </button>
            </div>
          </div>
        </div>
      )}
    </div>
  );
}